/**
 ****************************************************************************
 * @file     H_Hall.h
 * @brief    Motor vector control driver Header File
 * @version  V1.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2019
 *****************************************************************************
 */
#ifndef _H_HALL
#define _H_HALL

#undef EXTERN
#ifdef DEFINE_APP
#define EXTERN
#else
#define EXTERN  extern
#endif


/*===================================================================*
      Type Definition
 *===================================================================*/
#if (defined(__USE_HALL_CH1) && defined(__USE_ENCODER_CH1))
typedef struct
{
	uint16_t reserve: 12; 						/* reserve */
	uint16_t ele_correct: 1;					/* Electrical angle correction timing */
	uint16_t hall_rot: 1;						/* motor rotation by hall sensor 0:CCW ,1:CW */
	uint16_t enc_detect: 1;						/* Encoder detect state 0:None ,1:Detected */
	uint16_t hall_detect: 1;					/* Hall detect state 0:None ,1:Detected */
} sensor_flg;


typedef struct
{
	sensor_flg			SensorFlg;				/* Flag */

	uint16_t			EncPulseCnt;			/* Encoder pulse timer counter */

	uint16_t			theta_hall;				/* [---] Electrical angle by hall sensor */
	uint8_t				rot;					/* motor rotation by hall sonsor */

	uint8_t				ModeIdx, ModeIdx1;
	uint8_t				SensorPos;				/* Hall sensor port data */
	uint8_t				SensorPortPre;			/* Hall sensor port pre data */
	uint8_t				ChatCnt;				/* Hall sensor charing counter */

} Hall_t;
#endif /* (__USE_HALL_CH1 and __USE_ENCODER_CH1) */


/*===================================================================*
      Data Definition
 *===================================================================*/
#if defined(__USE_HALL_CH1) && defined(__USE_ENCODER_CH1)
EXTERN	Hall_t	Hall_ch1;
#endif /* __USE_HALL_CH1 and __USE_ENCODER_CH1 */


/*===================================================================*
      Constant Definition
 *===================================================================*/
#define	INTENC1Lv			INT_HALL_LEVEL
#define	INTENC0Lv			INT_HALL_LEVEL

#define	cCW					1
#define	cCCW				0

#define	c_HALL_CHAT			3				// Hall Sensor chataring count (every pwm period)


/*===================================================================*
      Proto Type Definition
 *===================================================================*/
#if (defined(__USE_HALL_CH1) && defined(__USE_ENCODER_CH1))
EXTERN	uint16_t	Get_EleAngleFromHall(Hall_t* const _hall, uint8_t _rot);
EXTERN	void		init_HallCon(Hall_t* const _hall);
EXTERN	void		H_HallCon(Hall_t* const _hall);
#endif /* (__USE_HALL_CH1 and __USE_ENCODER_CH1) */


#undef	EXTERN
#endif /* _H_HALL */
