/**
 ****************************************************************************
 * @file:	 main.c
 * @brief:	 main Functions
 * @version  V2.1
 *
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2019
 *****************************************************************************
 */
#include <stdlib.h>

#define DEFINE_APP
#include "ipdefine.h"
#undef	DEFINE_APP
#include "mcuip_drv.h"

#include "D_Driver.h"
#include "C_Control.h"
#include "B_User.h"
#include "initial.h"
#include "usercon.h"
#include "dac_drv.h"

#include "v7z_board.h"

/*===================================================================*
	Proto Type Definition
 *===================================================================*/
void main_loop(void);

/*===================================================================*
	Function
 *===================================================================*/

/**
 *********************************************************************************************
 * @brief		main Routine
 *
 * @return		int
 *********************************************************************************************
 */
 int main(void)
{	
	/***** Initial Setting *****/
	__disable_irq();									/* DI */

	init_WDT();											/* Initial setting of WDT */

#if defined(__RELAY)
	init_Relay();										/* Initial setting of Relay Port */
#endif
#if defined(__PRE_DRV_EN)
	init_PreDrvEn();
#endif

	init_TP();											/* Initial setting of Test point port */

#if defined(__USE_ENCODER_CH0) || defined(__USE_ENCODER_CH1) || defined(__USE_ENCODER_CH2)
	init_ENCen();										/* Initial setting of INTENC */
#endif /* __USE_ENCODER */

	init_ADCen();										/* Initial setting of ADC */
	init_PMDen();										/* Initial setting of PMD */
	init_VEen();										/* Initial setting of VE & start */

	B_Motor_Init();										/* Initial setting of the motor control. */
	init_user_control();								/* Initial setting of user control. */

#if defined(__USE_DAC)
	init_Dac(DAC_SIO_CH);								/* Initial setting of Dac controller */
#endif /* __USE_DAC */

#if defined(__USE_NBD)
	init_NBD();											/* Initial setting of N.B.D. */
#endif /* __USE_NBD */

	init_Timer_interval4kH();							/* Initial setting of interval timer. */

	__enable_irq(); 									/* EI */

#if defined(__RELAY)
	Relay_On();											/* Turn on Relay */
#endif

	SIWDT_WriteClearCode();
	
	/***** Main Loop *****/
	main_loop();
	return 0;
}

/**
 *********************************************************************************************
 * @brief		main_loop
 *
 * @return		none
 *********************************************************************************************
 */
void main_loop(void)
{
	while (1)
	{
		if (M_Main_Counter >= cMAINLOOP_CNT)
		{
			vector_t* motor_ch;
			M_Main_Counter = 0;

			/***** Clear WDT *****/
			SIWDT_WriteClearCode();

			/***** User control *****/
			user_control();

			/***** User motor control	*****/
			B_User_MotorControl();

			/***** Motor control  *****/
			/* Ch2 */
#if defined(__CONTROL_MOTOR_CH2)
			motor_ch = &Motor_ch2;

		#if defined(__USE_VE_CH2)
			D_SetZeroCurrentByVE(motor_ch, &Motor_ch2_IP);	/* Set Zero current */
		#else
			D_SetZeroCurrent(motor_ch);					/* Set Zero current */
		#endif
		#if defined(__USE_ENCODER_CH2) && (cSHUNT_TYPE_CH2 == 3)
			C_Control_Ref_Model_Enc(motor_ch);			/* Change of stage */
		#else
			C_Control_Ref_Model(motor_ch);				/* Change of stage */
		#endif /* __USE_ENCODER_CH2 */
			C_Common(motor_ch); 						/* Stage Functions */
			C_Stage_Stop(motor_ch); 					/* Stop */
			C_Stage_Emergency(motor_ch);				/* Emargency */
			C_Stage_Bootstrap(motor_ch);				/* Positioning */
			C_Stage_Initposition(motor_ch); 			/* Bootstrap */
			C_Stage_Force(motor_ch);					/* Force commutation */
			C_Stage_Change_up(motor_ch);				/* Change up */
			C_Stage_Steady_A(motor_ch); 				/* Normal RUN A (Speed control by currnt) */

		#if defined(__PRE_DRV_EN)
			PreDrvEn2_Control();
		#endif
			
#endif /* __CONTROL_MOTOR_CH2 */

			/* Ch1 */
#if defined(__CONTROL_MOTOR_CH1)
			motor_ch = &Motor_ch1;

		#if defined(__USE_VE_CH1)
			D_SetZeroCurrentByVE(motor_ch, &Motor_ch1_IP);	/* Set Zero current */
		#else
			D_SetZeroCurrent(motor_ch);					/* Set Zero current */
		#endif
		#if defined(__USE_ENCODER_CH1) && (cSHUNT_TYPE_CH1 == 3)
			C_Control_Ref_Model_Enc(motor_ch);			/* Change of stage */
		#else
			C_Control_Ref_Model(motor_ch);				/* Change of stage */
		#endif /* __USE_ENCODER_CH1 */
			C_Common(motor_ch); 						/* Stage Functions */
			C_Stage_Stop(motor_ch); 					/* Stop */
			C_Stage_Emergency(motor_ch);				/* Emargency */
			C_Stage_Bootstrap(motor_ch);				/* Positioning */
			C_Stage_Initposition(motor_ch); 			/* Bootstrap */
			C_Stage_Force(motor_ch);					/* Force commutation */
			C_Stage_Change_up(motor_ch);				/* Change up */
			C_Stage_Steady_A(motor_ch); 				/* Normal RUN A (Speed control by currnt) */

		#if defined(__PRE_DRV_EN)
			PreDrvEn1_Control();
		#endif
			
#endif /* __CONTROL_MOTOR_CH1 */

#if defined(__CONTROL_MOTOR_CH0)
			/* Ch0 */
			motor_ch = &Motor_ch0;

		#if defined(__USE_VE_CH0)
			D_SetZeroCurrentByVE(motor_ch, &Motor_ch0_IP);	/* Set Zero current */
		#else
			D_SetZeroCurrent(motor_ch);					/* Set Zero current */
		#endif
		#if defined(__USE_ENCODER_CH0) && (cSHUNT_TYPE_CH0 == 3)
			C_Control_Ref_Model_Enc(motor_ch);			/* Change of stage */
		#else
			C_Control_Ref_Model(motor_ch);				/* Change of stage */
		#endif /* __USE_ENCDER_CH0 */
			C_Common(motor_ch); 						/* Stage Functions */
			C_Stage_Stop(motor_ch); 					/* Stop */
			C_Stage_Emergency(motor_ch);				/* Emargency */
			C_Stage_Bootstrap(motor_ch);				/* Positioning */
			C_Stage_Initposition(motor_ch); 			/* Bootstrap */
			C_Stage_Force(motor_ch);					/* Force commutation */
			C_Stage_Change_up(motor_ch);				/* Change up */
			C_Stage_Steady_A(motor_ch); 				/* Normal RUN A (Speed control by currnt) */

		#if defined(__PRE_DRV_EN)
			PreDrvEn0_Control();
		#endif

#endif /* defined(__CONTROL_MOTOR_CH0) */

		}
	}
}


/*********************************** END OF FILE ******************************/
